"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NetworkConnectivityHubXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkConnectivityHubXTimeouts = NetworkConnectivityHubXTimeouts

@typing_extensions.final
class NetworkConnectivityHub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RoutingVpcsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROUTING_VPCS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def routing_vpcs(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    state: builtins.str
    unique_id: builtins.str
    update_time: builtins.str
    @property
    def timeouts(self) -> global___NetworkConnectivityHubXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        routing_vpcs: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        state: builtins.str = ...,
        unique_id: builtins.str = ...,
        update_time: builtins.str = ...,
        timeouts: global___NetworkConnectivityHubXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "resource_info", b"resource_info", "routing_vpcs", b"routing_vpcs", "state", b"state", "timeouts", b"timeouts", "unique_id", b"unique_id", "update_time", b"update_time"]) -> None: ...

global___NetworkConnectivityHub = NetworkConnectivityHub

@typing_extensions.final
class NetworkConnectivitySpokeXLinkedInterconnectAttachments(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SITE_TO_SITE_DATA_TRANSFER_FIELD_NUMBER: builtins.int
    URIS_FIELD_NUMBER: builtins.int
    site_to_site_data_transfer: builtins.bool
    @property
    def uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        site_to_site_data_transfer: builtins.bool = ...,
        uris: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["site_to_site_data_transfer", b"site_to_site_data_transfer", "uris", b"uris"]) -> None: ...

global___NetworkConnectivitySpokeXLinkedInterconnectAttachments = NetworkConnectivitySpokeXLinkedInterconnectAttachments

@typing_extensions.final
class NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_ADDRESS_FIELD_NUMBER: builtins.int
    VIRTUAL_MACHINE_FIELD_NUMBER: builtins.int
    ip_address: builtins.str
    virtual_machine: builtins.str
    def __init__(
        self,
        *,
        ip_address: builtins.str = ...,
        virtual_machine: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_address", b"ip_address", "virtual_machine", b"virtual_machine"]) -> None: ...

global___NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances = NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances

@typing_extensions.final
class NetworkConnectivitySpokeXLinkedRouterApplianceInstances(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SITE_TO_SITE_DATA_TRANSFER_FIELD_NUMBER: builtins.int
    INSTANCES_FIELD_NUMBER: builtins.int
    site_to_site_data_transfer: builtins.bool
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances]: ...
    def __init__(
        self,
        *,
        site_to_site_data_transfer: builtins.bool = ...,
        instances: collections.abc.Iterable[global___NetworkConnectivitySpokeXLinkedRouterApplianceInstancesXInstances] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instances", b"instances", "site_to_site_data_transfer", b"site_to_site_data_transfer"]) -> None: ...

global___NetworkConnectivitySpokeXLinkedRouterApplianceInstances = NetworkConnectivitySpokeXLinkedRouterApplianceInstances

@typing_extensions.final
class NetworkConnectivitySpokeXLinkedVpnTunnels(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SITE_TO_SITE_DATA_TRANSFER_FIELD_NUMBER: builtins.int
    URIS_FIELD_NUMBER: builtins.int
    site_to_site_data_transfer: builtins.bool
    @property
    def uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        site_to_site_data_transfer: builtins.bool = ...,
        uris: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["site_to_site_data_transfer", b"site_to_site_data_transfer", "uris", b"uris"]) -> None: ...

global___NetworkConnectivitySpokeXLinkedVpnTunnels = NetworkConnectivitySpokeXLinkedVpnTunnels

@typing_extensions.final
class NetworkConnectivitySpokeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkConnectivitySpokeXTimeouts = NetworkConnectivitySpokeXTimeouts

@typing_extensions.final
class NetworkConnectivitySpoke(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HUB_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UNIQUE_ID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    LINKED_INTERCONNECT_ATTACHMENTS_FIELD_NUMBER: builtins.int
    LINKED_ROUTER_APPLIANCE_INSTANCES_FIELD_NUMBER: builtins.int
    LINKED_VPN_TUNNELS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    hub: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    unique_id: builtins.str
    update_time: builtins.str
    @property
    def linked_interconnect_attachments(self) -> global___NetworkConnectivitySpokeXLinkedInterconnectAttachments: ...
    @property
    def linked_router_appliance_instances(self) -> global___NetworkConnectivitySpokeXLinkedRouterApplianceInstances: ...
    @property
    def linked_vpn_tunnels(self) -> global___NetworkConnectivitySpokeXLinkedVpnTunnels: ...
    @property
    def timeouts(self) -> global___NetworkConnectivitySpokeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        hub: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        unique_id: builtins.str = ...,
        update_time: builtins.str = ...,
        linked_interconnect_attachments: global___NetworkConnectivitySpokeXLinkedInterconnectAttachments | None = ...,
        linked_router_appliance_instances: global___NetworkConnectivitySpokeXLinkedRouterApplianceInstances | None = ...,
        linked_vpn_tunnels: global___NetworkConnectivitySpokeXLinkedVpnTunnels | None = ...,
        timeouts: global___NetworkConnectivitySpokeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["linked_interconnect_attachments", b"linked_interconnect_attachments", "linked_router_appliance_instances", b"linked_router_appliance_instances", "linked_vpn_tunnels", b"linked_vpn_tunnels", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "hub", b"hub", "id", b"id", "labels", b"labels", "linked_interconnect_attachments", b"linked_interconnect_attachments", "linked_router_appliance_instances", b"linked_router_appliance_instances", "linked_vpn_tunnels", b"linked_vpn_tunnels", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "unique_id", b"unique_id", "update_time", b"update_time"]) -> None: ...

global___NetworkConnectivitySpoke = NetworkConnectivitySpoke

@typing_extensions.final
class NetworkManagementConnectivityTestXDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    instance: builtins.str
    ip_address: builtins.str
    network: builtins.str
    port: builtins.float
    project_id: builtins.str
    def __init__(
        self,
        *,
        instance: builtins.str = ...,
        ip_address: builtins.str = ...,
        network: builtins.str = ...,
        port: builtins.float = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance", b"instance", "ip_address", b"ip_address", "network", b"network", "port", b"port", "project_id", b"project_id"]) -> None: ...

global___NetworkManagementConnectivityTestXDestination = NetworkManagementConnectivityTestXDestination

@typing_extensions.final
class NetworkManagementConnectivityTestXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCE_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_TYPE_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    instance: builtins.str
    ip_address: builtins.str
    network: builtins.str
    network_type: builtins.str
    port: builtins.float
    project_id: builtins.str
    def __init__(
        self,
        *,
        instance: builtins.str = ...,
        ip_address: builtins.str = ...,
        network: builtins.str = ...,
        network_type: builtins.str = ...,
        port: builtins.float = ...,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance", b"instance", "ip_address", b"ip_address", "network", b"network", "network_type", b"network_type", "port", b"port", "project_id", b"project_id"]) -> None: ...

global___NetworkManagementConnectivityTestXSource = NetworkManagementConnectivityTestXSource

@typing_extensions.final
class NetworkManagementConnectivityTestXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkManagementConnectivityTestXTimeouts = NetworkManagementConnectivityTestXTimeouts

@typing_extensions.final
class NetworkManagementConnectivityTest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RELATED_PROJECTS_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    protocol: builtins.str
    @property
    def related_projects(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def destination(self) -> global___NetworkManagementConnectivityTestXDestination: ...
    @property
    def source(self) -> global___NetworkManagementConnectivityTestXSource: ...
    @property
    def timeouts(self) -> global___NetworkManagementConnectivityTestXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        protocol: builtins.str = ...,
        related_projects: collections.abc.Iterable[builtins.str] | None = ...,
        destination: global___NetworkManagementConnectivityTestXDestination | None = ...,
        source: global___NetworkManagementConnectivityTestXSource | None = ...,
        timeouts: global___NetworkManagementConnectivityTestXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info", "source", b"source", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "destination", b"destination", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "protocol", b"protocol", "related_projects", b"related_projects", "resource_info", b"resource_info", "source", b"source", "timeouts", b"timeouts"]) -> None: ...

global___NetworkManagementConnectivityTest = NetworkManagementConnectivityTest

@typing_extensions.final
class NetworkServicesEdgeCacheKeysetXPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    id: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "value", b"value"]) -> None: ...

global___NetworkServicesEdgeCacheKeysetXPublicKey = NetworkServicesEdgeCacheKeysetXPublicKey

@typing_extensions.final
class NetworkServicesEdgeCacheKeysetXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkServicesEdgeCacheKeysetXTimeouts = NetworkServicesEdgeCacheKeysetXTimeouts

@typing_extensions.final
class NetworkServicesEdgeCacheKeyset(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    @property
    def public_key(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheKeysetXPublicKey]: ...
    @property
    def timeouts(self) -> global___NetworkServicesEdgeCacheKeysetXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        public_key: collections.abc.Iterable[global___NetworkServicesEdgeCacheKeysetXPublicKey] | None = ...,
        timeouts: global___NetworkServicesEdgeCacheKeysetXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "public_key", b"public_key", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___NetworkServicesEdgeCacheKeyset = NetworkServicesEdgeCacheKeyset

@typing_extensions.final
class NetworkServicesEdgeCacheOriginXTimeout(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECT_TIMEOUT_FIELD_NUMBER: builtins.int
    MAX_ATTEMPTS_TIMEOUT_FIELD_NUMBER: builtins.int
    READ_TIMEOUT_FIELD_NUMBER: builtins.int
    RESPONSE_TIMEOUT_FIELD_NUMBER: builtins.int
    connect_timeout: builtins.str
    max_attempts_timeout: builtins.str
    read_timeout: builtins.str
    response_timeout: builtins.str
    def __init__(
        self,
        *,
        connect_timeout: builtins.str = ...,
        max_attempts_timeout: builtins.str = ...,
        read_timeout: builtins.str = ...,
        response_timeout: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connect_timeout", b"connect_timeout", "max_attempts_timeout", b"max_attempts_timeout", "read_timeout", b"read_timeout", "response_timeout", b"response_timeout"]) -> None: ...

global___NetworkServicesEdgeCacheOriginXTimeout = NetworkServicesEdgeCacheOriginXTimeout

@typing_extensions.final
class NetworkServicesEdgeCacheOriginXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkServicesEdgeCacheOriginXTimeouts = NetworkServicesEdgeCacheOriginXTimeouts

@typing_extensions.final
class NetworkServicesEdgeCacheOrigin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    FAILOVER_ORIGIN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAX_ATTEMPTS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ORIGIN_ADDRESS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RETRY_CONDITIONS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    failover_origin: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    max_attempts: builtins.float
    name: builtins.str
    origin_address: builtins.str
    port: builtins.float
    project: builtins.str
    protocol: builtins.str
    @property
    def retry_conditions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timeout(self) -> global___NetworkServicesEdgeCacheOriginXTimeout: ...
    @property
    def timeouts(self) -> global___NetworkServicesEdgeCacheOriginXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        failover_origin: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        max_attempts: builtins.float = ...,
        name: builtins.str = ...,
        origin_address: builtins.str = ...,
        port: builtins.float = ...,
        project: builtins.str = ...,
        protocol: builtins.str = ...,
        retry_conditions: collections.abc.Iterable[builtins.str] | None = ...,
        timeout: global___NetworkServicesEdgeCacheOriginXTimeout | None = ...,
        timeouts: global___NetworkServicesEdgeCacheOriginXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeout", b"timeout", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "failover_origin", b"failover_origin", "id", b"id", "labels", b"labels", "max_attempts", b"max_attempts", "name", b"name", "origin_address", b"origin_address", "port", b"port", "project", b"project", "protocol", b"protocol", "resource_info", b"resource_info", "retry_conditions", b"retry_conditions", "timeout", b"timeout", "timeouts", b"timeouts"]) -> None: ...

global___NetworkServicesEdgeCacheOrigin = NetworkServicesEdgeCacheOrigin

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    sample_rate: builtins.float
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
        sample_rate: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable", "sample_rate", b"sample_rate"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXLogConfig = NetworkServicesEdgeCacheServiceXLogConfig

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXHostRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    HOSTS_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    description: builtins.str
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path_matcher: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        path_matcher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "hosts", b"hosts", "path_matcher", b"path_matcher"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXHostRule = NetworkServicesEdgeCacheServiceXRoutingXHostRule

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    HEADER_VALUE_FIELD_NUMBER: builtins.int
    REPLACE_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    header_value: builtins.str
    replace: builtins.bool
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
        header_value: builtins.str = ...,
        replace: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name", "header_value", b"header_value", "replace", b"replace"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_NAME_FIELD_NUMBER: builtins.int
    header_name: builtins.str
    def __init__(
        self,
        *,
        header_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["header_name", b"header_name"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_HEADER_TO_ADD_FIELD_NUMBER: builtins.int
    REQUEST_HEADER_TO_REMOVE_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_TO_ADD_FIELD_NUMBER: builtins.int
    RESPONSE_HEADER_TO_REMOVE_FIELD_NUMBER: builtins.int
    @property
    def request_header_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd]: ...
    @property
    def request_header_to_remove(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove]: ...
    @property
    def response_header_to_add(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd]: ...
    @property
    def response_header_to_remove(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove]: ...
    def __init__(
        self,
        *,
        request_header_to_add: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToAdd] | None = ...,
        request_header_to_remove: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXRequestHeaderToRemove] | None = ...,
        response_header_to_add: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToAdd] | None = ...,
        response_header_to_remove: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderActionXResponseHeaderToRemove] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_header_to_add", b"request_header_to_add", "request_header_to_remove", b"request_header_to_remove", "response_header_to_add", b"response_header_to_add", "response_header_to_remove", b"response_header_to_remove"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    HEADER_NAME_FIELD_NUMBER: builtins.int
    INVERT_MATCH_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    SUFFIX_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    header_name: builtins.str
    invert_match: builtins.bool
    prefix_match: builtins.str
    present_match: builtins.bool
    suffix_match: builtins.str
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        header_name: builtins.str = ...,
        invert_match: builtins.bool = ...,
        prefix_match: builtins.str = ...,
        present_match: builtins.bool = ...,
        suffix_match: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "header_name", b"header_name", "invert_match", b"invert_match", "prefix_match", b"prefix_match", "present_match", b"present_match", "suffix_match", b"suffix_match"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXACT_MATCH_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRESENT_MATCH_FIELD_NUMBER: builtins.int
    exact_match: builtins.str
    name: builtins.str
    present_match: builtins.bool
    def __init__(
        self,
        *,
        exact_match: builtins.str = ...,
        name: builtins.str = ...,
        present_match: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exact_match", b"exact_match", "name", b"name", "present_match", b"present_match"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FULL_PATH_MATCH_FIELD_NUMBER: builtins.int
    IGNORE_CASE_FIELD_NUMBER: builtins.int
    PATH_TEMPLATE_MATCH_FIELD_NUMBER: builtins.int
    PREFIX_MATCH_FIELD_NUMBER: builtins.int
    HEADER_MATCH_FIELD_NUMBER: builtins.int
    QUERY_PARAMETER_MATCH_FIELD_NUMBER: builtins.int
    full_path_match: builtins.str
    ignore_case: builtins.bool
    path_template_match: builtins.str
    prefix_match: builtins.str
    @property
    def header_match(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch]: ...
    @property
    def query_parameter_match(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch]: ...
    def __init__(
        self,
        *,
        full_path_match: builtins.str = ...,
        ignore_case: builtins.bool = ...,
        path_template_match: builtins.str = ...,
        prefix_match: builtins.str = ...,
        header_match: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXHeaderMatch] | None = ...,
        query_parameter_match: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRuleXQueryParameterMatch] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["full_path_match", b"full_path_match", "header_match", b"header_match", "ignore_case", b"ignore_case", "path_template_match", b"path_template_match", "prefix_match", b"prefix_match", "query_parameter_match", b"query_parameter_match"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXCLUDE_HOST_FIELD_NUMBER: builtins.int
    EXCLUDE_QUERY_STRING_FIELD_NUMBER: builtins.int
    EXCLUDED_QUERY_PARAMETERS_FIELD_NUMBER: builtins.int
    INCLUDE_PROTOCOL_FIELD_NUMBER: builtins.int
    INCLUDED_COOKIE_NAMES_FIELD_NUMBER: builtins.int
    INCLUDED_HEADER_NAMES_FIELD_NUMBER: builtins.int
    INCLUDED_QUERY_PARAMETERS_FIELD_NUMBER: builtins.int
    exclude_host: builtins.bool
    exclude_query_string: builtins.bool
    @property
    def excluded_query_parameters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_protocol: builtins.bool
    @property
    def included_cookie_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def included_header_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def included_query_parameters(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        exclude_host: builtins.bool = ...,
        exclude_query_string: builtins.bool = ...,
        excluded_query_parameters: collections.abc.Iterable[builtins.str] | None = ...,
        include_protocol: builtins.bool = ...,
        included_cookie_names: collections.abc.Iterable[builtins.str] | None = ...,
        included_header_names: collections.abc.Iterable[builtins.str] | None = ...,
        included_query_parameters: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclude_host", b"exclude_host", "exclude_query_string", b"exclude_query_string", "excluded_query_parameters", b"excluded_query_parameters", "include_protocol", b"include_protocol", "included_cookie_names", b"included_cookie_names", "included_header_names", b"included_header_names", "included_query_parameters", b"included_query_parameters"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NegativeCachingPolicyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CACHE_MODE_FIELD_NUMBER: builtins.int
    CLIENT_TTL_FIELD_NUMBER: builtins.int
    DEFAULT_TTL_FIELD_NUMBER: builtins.int
    MAX_TTL_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_FIELD_NUMBER: builtins.int
    NEGATIVE_CACHING_POLICY_FIELD_NUMBER: builtins.int
    SIGNED_REQUEST_KEYSET_FIELD_NUMBER: builtins.int
    SIGNED_REQUEST_MODE_FIELD_NUMBER: builtins.int
    CACHE_KEY_POLICY_FIELD_NUMBER: builtins.int
    cache_mode: builtins.str
    client_ttl: builtins.str
    default_ttl: builtins.str
    max_ttl: builtins.str
    negative_caching: builtins.bool
    @property
    def negative_caching_policy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    signed_request_keyset: builtins.str
    signed_request_mode: builtins.str
    @property
    def cache_key_policy(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy: ...
    def __init__(
        self,
        *,
        cache_mode: builtins.str = ...,
        client_ttl: builtins.str = ...,
        default_ttl: builtins.str = ...,
        max_ttl: builtins.str = ...,
        negative_caching: builtins.bool = ...,
        negative_caching_policy: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        signed_request_keyset: builtins.str = ...,
        signed_request_mode: builtins.str = ...,
        cache_key_policy: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicyXCacheKeyPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_key_policy", b"cache_key_policy", "cache_mode", b"cache_mode", "client_ttl", b"client_ttl", "default_ttl", b"default_ttl", "max_ttl", b"max_ttl", "negative_caching", b"negative_caching", "negative_caching_policy", b"negative_caching_policy", "signed_request_keyset", b"signed_request_keyset", "signed_request_mode", b"signed_request_mode"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CREDENTIALS_FIELD_NUMBER: builtins.int
    ALLOW_HEADERS_FIELD_NUMBER: builtins.int
    ALLOW_METHODS_FIELD_NUMBER: builtins.int
    ALLOW_ORIGINS_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    EXPOSE_HEADERS_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    allow_credentials: builtins.bool
    @property
    def allow_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def allow_origins(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    disabled: builtins.bool
    @property
    def expose_headers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    max_age: builtins.str
    def __init__(
        self,
        *,
        allow_credentials: builtins.bool = ...,
        allow_headers: collections.abc.Iterable[builtins.str] | None = ...,
        allow_methods: collections.abc.Iterable[builtins.str] | None = ...,
        allow_origins: collections.abc.Iterable[builtins.str] | None = ...,
        disabled: builtins.bool = ...,
        expose_headers: collections.abc.Iterable[builtins.str] | None = ...,
        max_age: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_credentials", b"allow_credentials", "allow_headers", b"allow_headers", "allow_methods", b"allow_methods", "allow_origins", b"allow_origins", "disabled", b"disabled", "expose_headers", b"expose_headers", "max_age", b"max_age"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REWRITE_FIELD_NUMBER: builtins.int
    PATH_PREFIX_REWRITE_FIELD_NUMBER: builtins.int
    PATH_TEMPLATE_REWRITE_FIELD_NUMBER: builtins.int
    host_rewrite: builtins.str
    path_prefix_rewrite: builtins.str
    path_template_rewrite: builtins.str
    def __init__(
        self,
        *,
        host_rewrite: builtins.str = ...,
        path_prefix_rewrite: builtins.str = ...,
        path_template_rewrite: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rewrite", b"host_rewrite", "path_prefix_rewrite", b"path_prefix_rewrite", "path_template_rewrite", b"path_template_rewrite"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CDN_POLICY_FIELD_NUMBER: builtins.int
    CORS_POLICY_FIELD_NUMBER: builtins.int
    URL_REWRITE_FIELD_NUMBER: builtins.int
    @property
    def cdn_policy(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy: ...
    @property
    def cors_policy(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy: ...
    @property
    def url_rewrite(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite: ...
    def __init__(
        self,
        *,
        cdn_policy: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCdnPolicy | None = ...,
        cors_policy: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXCorsPolicy | None = ...,
        url_rewrite: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteActionXUrlRewrite | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "cors_policy", b"cors_policy", "url_rewrite", b"url_rewrite"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cdn_policy", b"cdn_policy", "cors_policy", b"cors_policy", "url_rewrite", b"url_rewrite"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_REDIRECT_FIELD_NUMBER: builtins.int
    HTTPS_REDIRECT_FIELD_NUMBER: builtins.int
    PATH_REDIRECT_FIELD_NUMBER: builtins.int
    PREFIX_REDIRECT_FIELD_NUMBER: builtins.int
    REDIRECT_RESPONSE_CODE_FIELD_NUMBER: builtins.int
    STRIP_QUERY_FIELD_NUMBER: builtins.int
    host_redirect: builtins.str
    https_redirect: builtins.bool
    path_redirect: builtins.str
    prefix_redirect: builtins.str
    redirect_response_code: builtins.str
    strip_query: builtins.bool
    def __init__(
        self,
        *,
        host_redirect: builtins.str = ...,
        https_redirect: builtins.bool = ...,
        path_redirect: builtins.str = ...,
        prefix_redirect: builtins.str = ...,
        redirect_response_code: builtins.str = ...,
        strip_query: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_redirect", b"host_redirect", "https_redirect", b"https_redirect", "path_redirect", b"path_redirect", "prefix_redirect", b"prefix_redirect", "redirect_response_code", b"redirect_response_code", "strip_query", b"strip_query"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    HEADER_ACTION_FIELD_NUMBER: builtins.int
    MATCH_RULE_FIELD_NUMBER: builtins.int
    ROUTE_ACTION_FIELD_NUMBER: builtins.int
    URL_REDIRECT_FIELD_NUMBER: builtins.int
    description: builtins.str
    origin: builtins.str
    priority: builtins.str
    @property
    def header_action(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction: ...
    @property
    def match_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule]: ...
    @property
    def route_action(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction: ...
    @property
    def url_redirect(self) -> global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        origin: builtins.str = ...,
        priority: builtins.str = ...,
        header_action: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXHeaderAction | None = ...,
        match_rule: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXMatchRule] | None = ...,
        route_action: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXRouteAction | None = ...,
        url_redirect: global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRuleXUrlRedirect | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header_action", b"header_action", "route_action", b"route_action", "url_redirect", b"url_redirect"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "header_action", b"header_action", "match_rule", b"match_rule", "origin", b"origin", "priority", b"priority", "route_action", b"route_action", "url_redirect", b"url_redirect"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule = NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRoutingXPathMatcher(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ROUTE_RULE_FIELD_NUMBER: builtins.int
    description: builtins.str
    name: builtins.str
    @property
    def route_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule]: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        name: builtins.str = ...,
        route_rule: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcherXRouteRule] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "route_rule", b"route_rule"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcher = NetworkServicesEdgeCacheServiceXRoutingXPathMatcher

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXRouting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_RULE_FIELD_NUMBER: builtins.int
    PATH_MATCHER_FIELD_NUMBER: builtins.int
    @property
    def host_rule(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXHostRule]: ...
    @property
    def path_matcher(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcher]: ...
    def __init__(
        self,
        *,
        host_rule: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXHostRule] | None = ...,
        path_matcher: collections.abc.Iterable[global___NetworkServicesEdgeCacheServiceXRoutingXPathMatcher] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host_rule", b"host_rule", "path_matcher", b"path_matcher"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXRouting = NetworkServicesEdgeCacheServiceXRouting

@typing_extensions.final
class NetworkServicesEdgeCacheServiceXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___NetworkServicesEdgeCacheServiceXTimeouts = NetworkServicesEdgeCacheServiceXTimeouts

@typing_extensions.final
class NetworkServicesEdgeCacheService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLE_HTTP2_FIELD_NUMBER: builtins.int
    DISABLE_QUIC_FIELD_NUMBER: builtins.int
    EDGE_SECURITY_POLICY_FIELD_NUMBER: builtins.int
    EDGE_SSL_CERTIFICATES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IPV4_ADDRESSES_FIELD_NUMBER: builtins.int
    IPV6_ADDRESSES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REQUIRE_TLS_FIELD_NUMBER: builtins.int
    SSL_POLICY_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    ROUTING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    disable_http2: builtins.bool
    disable_quic: builtins.bool
    edge_security_policy: builtins.str
    @property
    def edge_ssl_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    @property
    def ipv4_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ipv6_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    require_tls: builtins.bool
    ssl_policy: builtins.str
    @property
    def log_config(self) -> global___NetworkServicesEdgeCacheServiceXLogConfig: ...
    @property
    def routing(self) -> global___NetworkServicesEdgeCacheServiceXRouting: ...
    @property
    def timeouts(self) -> global___NetworkServicesEdgeCacheServiceXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        disable_http2: builtins.bool = ...,
        disable_quic: builtins.bool = ...,
        edge_security_policy: builtins.str = ...,
        edge_ssl_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        ipv4_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        ipv6_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        require_tls: builtins.bool = ...,
        ssl_policy: builtins.str = ...,
        log_config: global___NetworkServicesEdgeCacheServiceXLogConfig | None = ...,
        routing: global___NetworkServicesEdgeCacheServiceXRouting | None = ...,
        timeouts: global___NetworkServicesEdgeCacheServiceXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["log_config", b"log_config", "resource_info", b"resource_info", "routing", b"routing", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disable_http2", b"disable_http2", "disable_quic", b"disable_quic", "edge_security_policy", b"edge_security_policy", "edge_ssl_certificates", b"edge_ssl_certificates", "id", b"id", "ipv4_addresses", b"ipv4_addresses", "ipv6_addresses", b"ipv6_addresses", "labels", b"labels", "log_config", b"log_config", "name", b"name", "project", b"project", "require_tls", b"require_tls", "resource_info", b"resource_info", "routing", b"routing", "ssl_policy", b"ssl_policy", "timeouts", b"timeouts"]) -> None: ...

global___NetworkServicesEdgeCacheService = NetworkServicesEdgeCacheService



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.authentication.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_io.k8s.api.authentication.v1.proto\x12%oak9.tython.k8s.api.authentication.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x8d\x01\n\x14\x42oundObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x02\n\x0cTokenRequest\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x45\n\x04spec\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.api.authentication.v1.TokenRequestSpec\x12I\n\x06status\x18\x05 \x01(\x0b\x32\x39.oak9.tython.k8s.api.authentication.v1.TokenRequestStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd1\x01\n\x10TokenRequestSpec\x12\x11\n\taudiences\x18\x01 \x03(\t\x12U\n\x10\x62ound_object_ref\x18\x02 \x01(\x0b\x32;.oak9.tython.k8s.api.authentication.v1.BoundObjectReference\x12\x1a\n\x12\x65xpiration_seconds\x18\x03 \x01(\x05\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xaf\x01\n\x12TokenRequestStatus\x12Q\n\x14\x65xpiration_timestamp\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05token\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc6\x02\n\x0bTokenReview\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x44\n\x04spec\x18\x04 \x01(\x0b\x32\x36.oak9.tython.k8s.api.authentication.v1.TokenReviewSpec\x12H\n\x06status\x18\x05 \x01(\x0b\x32\x38.oak9.tython.k8s.api.authentication.v1.TokenReviewStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"l\n\x0fTokenReviewSpec\x12\x11\n\taudiences\x18\x01 \x03(\t\x12\r\n\x05token\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x01\n\x11TokenReviewStatus\x12\x11\n\taudiences\x18\x01 \x03(\t\x12\x15\n\rauthenticated\x18\x02 \x01(\x08\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12=\n\x04user\x18\x04 \x01(\x0b\x32/.oak9.tython.k8s.api.authentication.v1.UserInfo\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xeb\x01\n\x08UserInfo\x12I\n\x05\x65xtra\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.api.authentication.v1.UserInfo.ExtraEntry\x12\x0e\n\x06groups\x18\x02 \x03(\t\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.authentication.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERINFO_EXTRAENTRY._options = None
  _USERINFO_EXTRAENTRY._serialized_options = b'8\001'
  _BOUNDOBJECTREFERENCE._serialized_start=187
  _BOUNDOBJECTREFERENCE._serialized_end=328
  _TOKENREQUEST._serialized_start=331
  _TOKENREQUEST._serialized_end=660
  _TOKENREQUESTSPEC._serialized_start=663
  _TOKENREQUESTSPEC._serialized_end=872
  _TOKENREQUESTSTATUS._serialized_start=875
  _TOKENREQUESTSTATUS._serialized_end=1050
  _TOKENREVIEW._serialized_start=1053
  _TOKENREVIEW._serialized_end=1379
  _TOKENREVIEWSPEC._serialized_start=1381
  _TOKENREVIEWSPEC._serialized_end=1489
  _TOKENREVIEWSTATUS._serialized_start=1492
  _TOKENREVIEWSTATUS._serialized_end=1688
  _USERINFO._serialized_start=1691
  _USERINFO._serialized_end=1926
  _USERINFO_EXTRAENTRY._serialized_start=1882
  _USERINFO_EXTRAENTRY._serialized_end=1926
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_router.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_router.proto\x12\x1eoak9.tython.gcp.compute_router\x1a\x13shared/shared.proto\"J\n$ComputeRouterXBgpXAdvertisedIpRanges\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05range\x18\x02 \x01(\t\"\xd3\x01\n\x11\x43omputeRouterXBgp\x12\x16\n\x0e\x61\x64vertise_mode\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64vertised_groups\x18\x02 \x03(\t\x12\x0b\n\x03\x61sn\x18\x03 \x01(\x01\x12\x1a\n\x12keepalive_interval\x18\x04 \x01(\x01\x12\x62\n\x14\x61\x64vertised_ip_ranges\x18\x05 \x03(\x0b\x32\x44.oak9.tython.gcp.compute_router.ComputeRouterXBgpXAdvertisedIpRanges\"H\n\x16\x43omputeRouterXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x89\x03\n\rComputeRouter\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12%\n\x1d\x65ncrypted_interconnect_router\x18\x03 \x01(\x08\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12>\n\x03\x62gp\x18\n \x01(\x0b\x32\x31.oak9.tython.gcp.compute_router.ComputeRouterXBgp\x12H\n\x08timeouts\x18\x0b \x01(\x0b\x32\x36.oak9.tython.gcp.compute_router.ComputeRouterXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeRouterInterfaceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xb6\x02\n\x16\x43omputeRouterInterface\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\x17interconnect_attachment\x18\x02 \x01(\t\x12\x10\n\x08ip_range\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0e\n\x06router\x18\x07 \x01(\t\x12\x12\n\nvpn_tunnel\x18\x08 \x01(\t\x12Q\n\x08timeouts\x18\t \x01(\x0b\x32?.oak9.tython.gcp.compute_router.ComputeRouterInterfaceXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"<\n\x1a\x43omputeRouterNatXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\"n\n\x1b\x43omputeRouterNatXSubnetwork\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18secondary_ip_range_names\x18\x02 \x03(\t\x12\x1f\n\x17source_ip_ranges_to_nat\x18\x03 \x03(\t\"K\n\x19\x43omputeRouterNatXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x91\x06\n\x10\x43omputeRouterNat\x12\x15\n\rdrain_nat_ips\x18\x01 \x03(\t\x12&\n\x1e\x65nable_dynamic_port_allocation\x18\x02 \x01(\x08\x12+\n#enable_endpoint_independent_mapping\x18\x03 \x01(\x08\x12\x1d\n\x15icmp_idle_timeout_sec\x18\x04 \x01(\x01\x12\n\n\x02id\x18\x05 \x01(\t\x12\x18\n\x10max_ports_per_vm\x18\x06 \x01(\x01\x12\x18\n\x10min_ports_per_vm\x18\x07 \x01(\x01\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1e\n\x16nat_ip_allocate_option\x18\t \x01(\t\x12\x0f\n\x07nat_ips\x18\n \x03(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x0e\n\x06router\x18\r \x01(\t\x12*\n\"source_subnetwork_ip_ranges_to_nat\x18\x0e \x01(\t\x12(\n tcp_established_idle_timeout_sec\x18\x0f \x01(\x01\x12\'\n\x1ftcp_transitory_idle_timeout_sec\x18\x10 \x01(\x01\x12\x1c\n\x14udp_idle_timeout_sec\x18\x11 \x01(\x01\x12N\n\nlog_config\x18\x12 \x01(\x0b\x32:.oak9.tython.gcp.compute_router.ComputeRouterNatXLogConfig\x12O\n\nsubnetwork\x18\x13 \x03(\x0b\x32;.oak9.tython.gcp.compute_router.ComputeRouterNatXSubnetwork\x12K\n\x08timeouts\x18\x14 \x01(\x0b\x32\x39.oak9.tython.gcp.compute_router.ComputeRouterNatXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"J\n$ComputeRouterPeerXAdvertisedIpRanges\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05range\x18\x02 \x01(\t\"\x8d\x01\n\x15\x43omputeRouterPeerXBfd\x12\x1c\n\x14min_receive_interval\x18\x01 \x01(\x01\x12\x1d\n\x15min_transmit_interval\x18\x02 \x01(\x01\x12\x12\n\nmultiplier\x18\x03 \x01(\x01\x12#\n\x1bsession_initialization_mode\x18\x04 \x01(\t\"L\n\x1a\x43omputeRouterPeerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xde\x04\n\x11\x43omputeRouterPeer\x12\x16\n\x0e\x61\x64vertise_mode\x18\x01 \x01(\t\x12\x19\n\x11\x61\x64vertised_groups\x18\x02 \x03(\t\x12!\n\x19\x61\x64vertised_route_priority\x18\x03 \x01(\x01\x12\x0e\n\x06\x65nable\x18\x04 \x01(\x08\x12\n\n\x02id\x18\x05 \x01(\t\x12\x11\n\tinterface\x18\x06 \x01(\t\x12\x12\n\nip_address\x18\x07 \x01(\t\x12\x17\n\x0fmanagement_type\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x10\n\x08peer_asn\x18\n \x01(\x01\x12\x17\n\x0fpeer_ip_address\x18\x0b \x01(\t\x12\x0f\n\x07project\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x0e\n\x06router\x18\x0e \x01(\t\x12\x62\n\x14\x61\x64vertised_ip_ranges\x18\x0f \x03(\x0b\x32\x44.oak9.tython.gcp.compute_router.ComputeRouterPeerXAdvertisedIpRanges\x12\x42\n\x03\x62\x66\x64\x18\x10 \x01(\x0b\x32\x35.oak9.tython.gcp.compute_router.ComputeRouterPeerXBfd\x12L\n\x08timeouts\x18\x11 \x01(\x0b\x32:.oak9.tython.gcp.compute_router.ComputeRouterPeerXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_router_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEROUTERXBGPXADVERTISEDIPRANGES._serialized_start=85
  _COMPUTEROUTERXBGPXADVERTISEDIPRANGES._serialized_end=159
  _COMPUTEROUTERXBGP._serialized_start=162
  _COMPUTEROUTERXBGP._serialized_end=373
  _COMPUTEROUTERXTIMEOUTS._serialized_start=375
  _COMPUTEROUTERXTIMEOUTS._serialized_end=447
  _COMPUTEROUTER._serialized_start=450
  _COMPUTEROUTER._serialized_end=843
  _COMPUTEROUTERINTERFACEXTIMEOUTS._serialized_start=845
  _COMPUTEROUTERINTERFACEXTIMEOUTS._serialized_end=910
  _COMPUTEROUTERINTERFACE._serialized_start=913
  _COMPUTEROUTERINTERFACE._serialized_end=1223
  _COMPUTEROUTERNATXLOGCONFIG._serialized_start=1225
  _COMPUTEROUTERNATXLOGCONFIG._serialized_end=1285
  _COMPUTEROUTERNATXSUBNETWORK._serialized_start=1287
  _COMPUTEROUTERNATXSUBNETWORK._serialized_end=1397
  _COMPUTEROUTERNATXTIMEOUTS._serialized_start=1399
  _COMPUTEROUTERNATXTIMEOUTS._serialized_end=1474
  _COMPUTEROUTERNAT._serialized_start=1477
  _COMPUTEROUTERNAT._serialized_end=2262
  _COMPUTEROUTERPEERXADVERTISEDIPRANGES._serialized_start=2264
  _COMPUTEROUTERPEERXADVERTISEDIPRANGES._serialized_end=2338
  _COMPUTEROUTERPEERXBFD._serialized_start=2341
  _COMPUTEROUTERPEERXBFD._serialized_end=2482
  _COMPUTEROUTERPEERXTIMEOUTS._serialized_start=2484
  _COMPUTEROUTERPEERXTIMEOUTS._serialized_end=2560
  _COMPUTEROUTERPEER._serialized_start=2563
  _COMPUTEROUTERPEER._serialized_end=3169
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_containerregistry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-azure/azure_microsoft_containerregistry.proto\x12-oak9.tython.azure.microsoft_containerregistry\x1a\x13shared/shared.proto\"l\n\x1bMicrosoft_ContainerRegistry\x12M\n\nregistries\x18\x01 \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_containerregistry.Registries\"\xde\x03\n\x12RegistriesWebhooks\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63tions\x18\x04 \x03(\t\x12l\n\x0e\x63ustom_headers\x18\x05 \x03(\x0b\x32T.oak9.tython.azure.microsoft_containerregistry.RegistriesWebhooks.CustomHeadersEntry\x12\r\n\x05scope\x18\x06 \x01(\t\x12\x13\n\x0bservice_uri\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12Y\n\x04tags\x18\t \x03(\x0b\x32K.oak9.tython.azure.microsoft_containerregistry.RegistriesWebhooks.TagsEntry\x1a\x34\n\x12\x43ustomHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdf\x01\n\x10RegistriesTokens\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12^\n\x0b\x63redentials\x18\x03 \x01(\x0b\x32I.oak9.tython.azure.microsoft_containerregistry.TokenCredentialsProperties\x12\x14\n\x0cscope_map_id\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\"\xc4\x01\n\x1aTokenCredentialsProperties\x12U\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerregistry.TokenCertificate\x12O\n\tpasswords\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_containerregistry.TokenPassword\"D\n\rTokenPassword\x12\x15\n\rcreation_time\x18\x01 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"e\n\x10TokenCertificate\x12\x1f\n\x17\x65ncoded_pem_certificate\x18\x01 \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nthumbprint\x18\x04 \x01(\t\"\x82\x01\n\x13RegistriesScopeMaps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x63tions\x18\x03 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\xb7\x02\n\x16RegistriesReplications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1f\n\x17region_endpoint_enabled\x18\x04 \x01(\x08\x12\x17\n\x0fzone_redundancy\x18\x05 \x01(\t\x12]\n\x04tags\x18\x06 \x03(\x0b\x32O.oak9.tython.azure.microsoft_containerregistry.RegistriesReplications.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc8\x02\n$RegistriesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12X\n\x10private_endpoint\x18\x03 \x01(\x0b\x32>.oak9.tython.azure.microsoft_containerregistry.PrivateEndpoint\x12\x7f\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32P.oak9.tython.azure.microsoft_containerregistry.PrivateLinkServiceConnectionState\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xcd\x01\n\x16RegistriesPipelineRuns\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10\x66orce_update_tag\x18\x03 \x01(\t\x12R\n\x07request\x18\x04 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.PipelineRunRequest\"\x95\x02\n\x12PipelineRunRequest\x12\x11\n\tartifacts\x18\x01 \x03(\t\x12\x16\n\x0e\x63\x61talog_digest\x18\x02 \x01(\t\x12\x1c\n\x14pipeline_resource_id\x18\x03 \x01(\t\x12Z\n\x06source\x18\x04 \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerregistry.PipelineRunSourceProperties\x12Z\n\x06target\x18\x05 \x01(\x0b\x32J.oak9.tython.azure.microsoft_containerregistry.PipelineRunTargetProperties\"9\n\x1bPipelineRunTargetProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"9\n\x1bPipelineRunSourceProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x94\x03\n\x19RegistriesImportPipelines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x08identity\x18\x02 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.IdentityProperties\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07options\x18\x05 \x03(\t\x12]\n\x06source\x18\x06 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerregistry.ImportPipelineSourceProperties\x12Y\n\x07trigger\x18\x07 \x01(\x0b\x32H.oak9.tython.azure.microsoft_containerregistry.PipelineTriggerProperties\"\x83\x01\n\x19PipelineTriggerProperties\x12\x66\n\x0esource_trigger\x18\x01 \x01(\x0b\x32N.oak9.tython.azure.microsoft_containerregistry.PipelineSourceTriggerProperties\"1\n\x1fPipelineSourceTriggerProperties\x12\x0e\n\x06status\x18\x01 \x01(\t\"R\n\x1eImportPipelineSourceProperties\x12\x15\n\rkey_vault_uri\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xb9\x02\n\x19RegistriesExportPipelines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x08identity\x18\x02 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.IdentityProperties\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07options\x18\x05 \x03(\t\x12]\n\x06target\x18\x06 \x01(\x0b\x32M.oak9.tython.azure.microsoft_containerregistry.ExportPipelineTargetProperties\"R\n\x1e\x45xportPipelineTargetProperties\x12\x15\n\rkey_vault_uri\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\xaa\x03\n\x1dRegistriesConnectedRegistries\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10\x63lient_token_ids\x18\x03 \x03(\t\x12Q\n\x07logging\x18\x04 \x01(\x0b\x32@.oak9.tython.azure.microsoft_containerregistry.LoggingProperties\x12Z\n\x0clogin_server\x18\x05 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_containerregistry.LoginServerProperties\x12\x0c\n\x04mode\x18\x06 \x01(\t\x12\x1a\n\x12notifications_list\x18\x07 \x03(\t\x12O\n\x06parent\x18\x08 \x01(\x0b\x32?.oak9.tython.azure.microsoft_containerregistry.ParentProperties\"v\n\x10ParentProperties\x12\n\n\x02id\x18\x01 \x01(\t\x12V\n\x0fsync_properties\x18\x02 \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerregistry.SyncProperties\"^\n\x0eSyncProperties\x12\x13\n\x0bmessage_ttl\x18\x01 \x01(\t\x12\x10\n\x08schedule\x18\x02 \x01(\t\x12\x13\n\x0bsync_window\x18\x03 \x01(\t\x12\x10\n\x08token_id\x18\x04 \x01(\t\"%\n\x15LoginServerProperties\x12\x0c\n\x04name\x18\x01 \x01(\t\"@\n\x11LoggingProperties\x12\x18\n\x10\x61udit_log_status\x18\x01 \x01(\t\x12\x11\n\tlog_level\x18\x02 \x01(\t\"\xfa\r\n\nRegistries\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x08identity\x18\x02 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.IdentityProperties\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1a\n\x12\x61\x64min_user_enabled\x18\x05 \x01(\x08\x12\x1e\n\x16\x61nonymous_pull_enabled\x18\x06 \x01(\x08\x12\x1d\n\x15\x64\x61ta_endpoint_enabled\x18\x07 \x01(\x08\x12U\n\nencryption\x18\x08 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.EncryptionProperty\x12#\n\x1bnetwork_rule_bypass_options\x18\t \x01(\t\x12W\n\x10network_rule_set\x18\n \x01(\x0b\x32=.oak9.tython.azure.microsoft_containerregistry.NetworkRuleSet\x12I\n\x08policies\x18\x0b \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_containerregistry.Policies\x12\x1d\n\x15public_network_access\x18\x0c \x01(\t\x12\x17\n\x0fzone_redundancy\x18\r \x01(\t\x12?\n\x03sku\x18\x0e \x01(\x0b\x32\x32.oak9.tython.azure.microsoft_containerregistry.Sku\x12Q\n\x04tags\x18\x0f \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_containerregistry.Registries.TagsEntry\x12u\n\x1fregistries_connected_registries\x18\x10 \x03(\x0b\x32L.oak9.tython.azure.microsoft_containerregistry.RegistriesConnectedRegistries\x12m\n\x1bregistries_export_pipelines\x18\x11 \x03(\x0b\x32H.oak9.tython.azure.microsoft_containerregistry.RegistriesExportPipelines\x12m\n\x1bregistries_import_pipelines\x18\x12 \x03(\x0b\x32H.oak9.tython.azure.microsoft_containerregistry.RegistriesImportPipelines\x12g\n\x18registries_pipeline_runs\x18\x13 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_containerregistry.RegistriesPipelineRuns\x12\x84\x01\n\'registries_private_endpoint_connections\x18\x14 \x03(\x0b\x32S.oak9.tython.azure.microsoft_containerregistry.RegistriesPrivateEndpointConnections\x12\x66\n\x17registries_replications\x18\x15 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_containerregistry.RegistriesReplications\x12\x61\n\x15registries_scope_maps\x18\x16 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_containerregistry.RegistriesScopeMaps\x12Z\n\x11registries_tokens\x18\x17 \x03(\x0b\x32?.oak9.tython.azure.microsoft_containerregistry.RegistriesTokens\x12^\n\x13registries_webhooks\x18\x18 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.RegistriesWebhooks\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x13\n\x03Sku\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe6\x02\n\x08Policies\x12R\n\rexport_policy\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_containerregistry.ExportPolicy\x12Z\n\x11quarantine_policy\x18\x02 \x01(\x0b\x32?.oak9.tython.azure.microsoft_containerregistry.QuarantinePolicy\x12X\n\x10retention_policy\x18\x03 \x01(\x0b\x32>.oak9.tython.azure.microsoft_containerregistry.RetentionPolicy\x12P\n\x0ctrust_policy\x18\x04 \x01(\x0b\x32:.oak9.tython.azure.microsoft_containerregistry.TrustPolicy\"+\n\x0bTrustPolicy\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"/\n\x0fRetentionPolicy\x12\x0c\n\x04\x64\x61ys\x18\x01 \x01(\x05\x12\x0e\n\x06status\x18\x02 \x01(\t\"\"\n\x10QuarantinePolicy\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x1e\n\x0c\x45xportPolicy\x12\x0e\n\x06status\x18\x01 \x01(\t\"\xd3\x01\n\x0eNetworkRuleSet\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x01 \x01(\t\x12G\n\x08ip_rules\x18\x02 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_containerregistry.IPRule\x12`\n\x15virtual_network_rules\x18\x03 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.VirtualNetworkRule\"0\n\x12VirtualNetworkRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"\'\n\x06IPRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x85\x01\n\x12\x45ncryptionProperty\x12_\n\x14key_vault_properties\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_containerregistry.KeyVaultProperties\x12\x0e\n\x06status\x18\x02 \x01(\t\">\n\x12KeyVaultProperties\x12\x10\n\x08identity\x18\x01 \x01(\t\x12\x16\n\x0ekey_identifier\x18\x02 \x01(\t\"\x8b\x02\n\x12IdentityProperties\x12\x14\n\x0cprincipal_id\x18\x01 \x01(\t\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x7f\n\x18user_assigned_identities\x18\x04 \x03(\x0b\x32].oak9.tython.azure.microsoft_containerregistry.IdentityProperties.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_containerregistry_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTRIESWEBHOOKS_CUSTOMHEADERSENTRY._options = None
  _REGISTRIESWEBHOOKS_CUSTOMHEADERSENTRY._serialized_options = b'8\001'
  _REGISTRIESWEBHOOKS_TAGSENTRY._options = None
  _REGISTRIESWEBHOOKS_TAGSENTRY._serialized_options = b'8\001'
  _REGISTRIESREPLICATIONS_TAGSENTRY._options = None
  _REGISTRIESREPLICATIONS_TAGSENTRY._serialized_options = b'8\001'
  _REGISTRIES_TAGSENTRY._options = None
  _REGISTRIES_TAGSENTRY._serialized_options = b'8\001'
  _IDENTITYPROPERTIES_USERASSIGNEDIDENTITIESENTRY._options = None
  _IDENTITYPROPERTIES_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_CONTAINERREGISTRY._serialized_start=117
  _MICROSOFT_CONTAINERREGISTRY._serialized_end=225
  _REGISTRIESWEBHOOKS._serialized_start=228
  _REGISTRIESWEBHOOKS._serialized_end=706
  _REGISTRIESWEBHOOKS_CUSTOMHEADERSENTRY._serialized_start=609
  _REGISTRIESWEBHOOKS_CUSTOMHEADERSENTRY._serialized_end=661
  _REGISTRIESWEBHOOKS_TAGSENTRY._serialized_start=663
  _REGISTRIESWEBHOOKS_TAGSENTRY._serialized_end=706
  _REGISTRIESTOKENS._serialized_start=709
  _REGISTRIESTOKENS._serialized_end=932
  _TOKENCREDENTIALSPROPERTIES._serialized_start=935
  _TOKENCREDENTIALSPROPERTIES._serialized_end=1131
  _TOKENPASSWORD._serialized_start=1133
  _TOKENPASSWORD._serialized_end=1201
  _TOKENCERTIFICATE._serialized_start=1203
  _TOKENCERTIFICATE._serialized_end=1304
  _REGISTRIESSCOPEMAPS._serialized_start=1307
  _REGISTRIESSCOPEMAPS._serialized_end=1437
  _REGISTRIESREPLICATIONS._serialized_start=1440
  _REGISTRIESREPLICATIONS._serialized_end=1751
  _REGISTRIESREPLICATIONS_TAGSENTRY._serialized_start=663
  _REGISTRIESREPLICATIONS_TAGSENTRY._serialized_end=706
  _REGISTRIESPRIVATEENDPOINTCONNECTIONS._serialized_start=1754
  _REGISTRIESPRIVATEENDPOINTCONNECTIONS._serialized_end=2082
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=2084
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=2182
  _PRIVATEENDPOINT._serialized_start=2184
  _PRIVATEENDPOINT._serialized_end=2213
  _REGISTRIESPIPELINERUNS._serialized_start=2216
  _REGISTRIESPIPELINERUNS._serialized_end=2421
  _PIPELINERUNREQUEST._serialized_start=2424
  _PIPELINERUNREQUEST._serialized_end=2701
  _PIPELINERUNTARGETPROPERTIES._serialized_start=2703
  _PIPELINERUNTARGETPROPERTIES._serialized_end=2760
  _PIPELINERUNSOURCEPROPERTIES._serialized_start=2762
  _PIPELINERUNSOURCEPROPERTIES._serialized_end=2819
  _REGISTRIESIMPORTPIPELINES._serialized_start=2822
  _REGISTRIESIMPORTPIPELINES._serialized_end=3226
  _PIPELINETRIGGERPROPERTIES._serialized_start=3229
  _PIPELINETRIGGERPROPERTIES._serialized_end=3360
  _PIPELINESOURCETRIGGERPROPERTIES._serialized_start=3362
  _PIPELINESOURCETRIGGERPROPERTIES._serialized_end=3411
  _IMPORTPIPELINESOURCEPROPERTIES._serialized_start=3413
  _IMPORTPIPELINESOURCEPROPERTIES._serialized_end=3495
  _REGISTRIESEXPORTPIPELINES._serialized_start=3498
  _REGISTRIESEXPORTPIPELINES._serialized_end=3811
  _EXPORTPIPELINETARGETPROPERTIES._serialized_start=3813
  _EXPORTPIPELINETARGETPROPERTIES._serialized_end=3895
  _REGISTRIESCONNECTEDREGISTRIES._serialized_start=3898
  _REGISTRIESCONNECTEDREGISTRIES._serialized_end=4324
  _PARENTPROPERTIES._serialized_start=4326
  _PARENTPROPERTIES._serialized_end=4444
  _SYNCPROPERTIES._serialized_start=4446
  _SYNCPROPERTIES._serialized_end=4540
  _LOGINSERVERPROPERTIES._serialized_start=4542
  _LOGINSERVERPROPERTIES._serialized_end=4579
  _LOGGINGPROPERTIES._serialized_start=4581
  _LOGGINGPROPERTIES._serialized_end=4645
  _REGISTRIES._serialized_start=4648
  _REGISTRIES._serialized_end=6434
  _REGISTRIES_TAGSENTRY._serialized_start=663
  _REGISTRIES_TAGSENTRY._serialized_end=706
  _SKU._serialized_start=6436
  _SKU._serialized_end=6455
  _POLICIES._serialized_start=6458
  _POLICIES._serialized_end=6816
  _TRUSTPOLICY._serialized_start=6818
  _TRUSTPOLICY._serialized_end=6861
  _RETENTIONPOLICY._serialized_start=6863
  _RETENTIONPOLICY._serialized_end=6910
  _QUARANTINEPOLICY._serialized_start=6912
  _QUARANTINEPOLICY._serialized_end=6946
  _EXPORTPOLICY._serialized_start=6948
  _EXPORTPOLICY._serialized_end=6978
  _NETWORKRULESET._serialized_start=6981
  _NETWORKRULESET._serialized_end=7192
  _VIRTUALNETWORKRULE._serialized_start=7194
  _VIRTUALNETWORKRULE._serialized_end=7242
  _IPRULE._serialized_start=7244
  _IPRULE._serialized_end=7283
  _ENCRYPTIONPROPERTY._serialized_start=7286
  _ENCRYPTIONPROPERTY._serialized_end=7419
  _KEYVAULTPROPERTIES._serialized_start=7421
  _KEYVAULTPROPERTIES._serialized_end=7483
  _IDENTITYPROPERTIES._serialized_start=7486
  _IDENTITYPROPERTIES._serialized_end=7753
  _IDENTITYPROPERTIES_USERASSIGNEDIDENTITIESENTRY._serialized_start=7692
  _IDENTITYPROPERTIES_USERASSIGNEDIDENTITIESENTRY._serialized_end=7753
# @@protoc_insertion_point(module_scope)
